@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 """SMTP class file."""
 
+import logging
 import smtplib
 from email.message import EmailMessage
 from email.utils import make_msgid
@@ -42,7 +43,7 @@ class SMTP(object):
         # attempt to send the message
         try:
             self.smtp.send_message(msg)
-            print(f"Email Successfully sent to: {to}")
+            return True
         except smtplib.SMTPException as e:
-            print(f'ERROR sending email to: {to}')
-            print(e)
+            logging.error('ERROR sending email to: %s: %s', to, e)
+            return False
